@@ -1,3 +1,6 @@
+from metrics_layer.core.exceptions import QueryError
+
+
 class Manifest:
     def __init__(self, definition: dict):
         self._definition = definition
@@ -8,7 +11,7 @@ class Manifest:
     def _resolve_node(self, name: str):
         key = next((k for k in self._definition["nodes"].keys() if name == k.split(".")[-1]), None)
         if key is None:
-            raise ValueError(
+            raise QueryError(
                 f"Could not find the ref {name} in the co-located dbt project."
                 " Please check the name in your dbt project."
             )
@@ -16,5 +19,4 @@ class Manifest:
 
     def resolve_name(self, name: str):
         node = self._resolve_node(name)
-        # return f"{node['database']}.{node['schema']}.{node['alias']}"
         return f"{node['schema']}.{node['alias']}"
