@@ -23,6 +23,10 @@ class MetricsLayerDesign:
         self._joins = None
         self._required_views = None
 
+    @property
+    def week_start_day(self):
+        return self.model.week_start_day
+
     def views(self) -> List[MetricsLayerBase]:
         return self.project.views(model=self.model)
 
