@@ -79,14 +79,17 @@ class MetricsLayerFilter(MetricsLayerBase):
         if definition.get("value", None) is None and definition["expression"] not in no_expr:
             raise ParseError(f"Filter expression: {definition['expression']} needs a non-empty value.")
 
+        if self.design:
+            self.week_start_day = self.design.week_start_day
+        else:
+            self.week_start_day = None
+
         if self.design and not is_boolean_value:
             # Will raise ParseError if not found
             try:
                 self.field = self.design.get_field(key)
             except ParseError:
-                raise ParseError(
-                    f"We could not find field {self.field_name} in explore {self.design.explore.name}"
-                )
+                raise ParseError(f"We could not find field {self.field_name}")
 
             if self.design.query_type == "BIGQUERY" and isinstance(definition["value"], datetime.datetime):
                 definition["value"] = bigquery_cast(self.field, definition["value"])
@@ -161,7 +164,12 @@ class MetricsLayerFilter(MetricsLayerBase):
         """
         if self.expression_type == MetricsLayerFilterExpressionType.Matches:
             criteria = []
-            for f in Filter({"field": self.field.alias(), "value": self.value}).filter_dict():
+            filter_dict = {
+                "field": self.field.alias(),
+                "value": self.value,
+                "week_start_day": self.week_start_day,
+            }
+            for f in Filter(filter_dict).filter_dict():
                 if self.query_type == Definitions.bigquery:
                     value = bigquery_cast(self.field, f["value"])
                 else:
